#ifndef _about_h__
#define _about_h__

#include <QVBoxLayout>
#include <QWidget>

class About : public QWidget {
    Q_OBJECT

  public:
    About();
    ~About();

  private:
    QVBoxLayout *lay;
};

#endif // _about_h__
